@@ -52,12 +52,15 @@ var searchData=
   ['opus_5fencoder_5fdestroy',['opus_encoder_destroy',['../group__opus__encoder.html#ga5f4c05b4b51cdffec5a55dbf17bbfa1c',1,'opus.h']]],
   ['opus_5fencoder_5fget_5fsize',['opus_encoder_get_size',['../group__opus__encoder.html#gaefeb7dc1d6e3b59dea5ea674c86e9c18',1,'opus.h']]],
   ['opus_5fencoder_5finit',['opus_encoder_init',['../group__opus__encoder.html#ga515db1c267a7421dacaad3610f79eb79',1,'opus.h']]],
+  ['opus_5fframesize_5f100_5fms',['OPUS_FRAMESIZE_100_MS',['../group__opus__ctlvalues.html#ga0ac306775a5e3000917110928385f9b0',1,'opus_defines.h']]],
   ['opus_5fframesize_5f10_5fms',['OPUS_FRAMESIZE_10_MS',['../group__opus__ctlvalues.html#ga39d5606c61c4cd21e6ae2f1259a1f15f',1,'opus_defines.h']]],
+  ['opus_5fframesize_5f120_5fms',['OPUS_FRAMESIZE_120_MS',['../group__opus__ctlvalues.html#gaeae3c8841942991e3c0ff763113e99ce',1,'opus_defines.h']]],
   ['opus_5fframesize_5f20_5fms',['OPUS_FRAMESIZE_20_MS',['../group__opus__ctlvalues.html#gacfce47959bdaa8581fdc68cec3be2bfb',1,'opus_defines.h']]],
   ['opus_5fframesize_5f2_5f5_5fms',['OPUS_FRAMESIZE_2_5_MS',['../group__opus__ctlvalues.html#ga4696f62216f4afb1493471bb4c25baea',1,'opus_defines.h']]],
   ['opus_5fframesize_5f40_5fms',['OPUS_FRAMESIZE_40_MS',['../group__opus__ctlvalues.html#ga268935a23f6d8a8ae6bb3d11ac6ae172',1,'opus_defines.h']]],
   ['opus_5fframesize_5f5_5fms',['OPUS_FRAMESIZE_5_MS',['../group__opus__ctlvalues.html#gab2e88add9d69a0828ca23efc7bbb41be',1,'opus_defines.h']]],
   ['opus_5fframesize_5f60_5fms',['OPUS_FRAMESIZE_60_MS',['../group__opus__ctlvalues.html#gac8178be7f02dc908c022cc3bb5c6c252',1,'opus_defines.h']]],
+  ['opus_5fframesize_5f80_5fms',['OPUS_FRAMESIZE_80_MS',['../group__opus__ctlvalues.html#ga2d9c1118aaaa1adfc5e08ffde36b24eb',1,'opus_defines.h']]],
   ['opus_5fframesize_5farg',['OPUS_FRAMESIZE_ARG',['../group__opus__ctlvalues.html#ga0371f264203138ca92a3705c9c0ac39d',1,'opus_defines.h']]],
   ['opus_5fget_5fapplication',['OPUS_GET_APPLICATION',['../group__opus__encoderctls.html#ga062ebbc209caf6832fe4a309a459fd4c',1,'opus_defines.h']]],
   ['opus_5fget_5fbandwidth',['OPUS_GET_BANDWIDTH',['../group__opus__genericctls.html#ga29db1d9b5e670debec54d1163ad2ec62',1,'opus_defines.h']]],
@@ -68,12 +71,14 @@ var searchData=
   ['opus_5fget_5ffinal_5frange',['OPUS_GET_FINAL_RANGE',['../group__opus__genericctls.html#ga1108a508aa475f964d247c1b04d26d89',1,'opus_defines.h']]],
   ['opus_5fget_5fforce_5fchannels',['OPUS_GET_FORCE_CHANNELS',['../group__opus__encoderctls.html#ga21f010167c5dfa1b53f20c46d473e86a',1,'opus_defines.h']]],
   ['opus_5fget_5fgain',['OPUS_GET_GAIN',['../group__opus__decoderctls.html#ga00ca8b4bd753a837f143ebd8ed63d247',1,'opus_defines.h']]],
+  ['opus_5fget_5fin_5fdtx',['OPUS_GET_IN_DTX',['../group__opus__genericctls.html#ga9af68dcfb4f136dd91b1050658d559ca',1,'opus_defines.h']]],
   ['opus_5fget_5finband_5ffec',['OPUS_GET_INBAND_FEC',['../group__opus__encoderctls.html#gaf792b27a6277ddf786413dbf472d0ac8',1,'opus_defines.h']]],
   ['opus_5fget_5flast_5fpacket_5fduration',['OPUS_GET_LAST_PACKET_DURATION',['../group__opus__decoderctls.html#ga8f3d070f56b75f2a7af54e5776b387fa',1,'opus_defines.h']]],
   ['opus_5fget_5flookahead',['OPUS_GET_LOOKAHEAD',['../group__opus__encoderctls.html#gaf81b9e01501910adc67195ebb42b4a54',1,'opus_defines.h']]],
   ['opus_5fget_5flsb_5fdepth',['OPUS_GET_LSB_DEPTH',['../group__opus__encoderctls.html#gab5ecdfbbbabfaefc2f2ca79cf4a3b08f',1,'opus_defines.h']]],
   ['opus_5fget_5fmax_5fbandwidth',['OPUS_GET_MAX_BANDWIDTH',['../group__opus__encoderctls.html#gaa3b5736de64792e1144ce12dfb87613c',1,'opus_defines.h']]],
   ['opus_5fget_5fpacket_5floss_5fperc',['OPUS_GET_PACKET_LOSS_PERC',['../group__opus__encoderctls.html#gaa79261c6a55444993fca8d3a3a29d519',1,'opus_defines.h']]],
+  ['opus_5fget_5fphase_5finversion_5fdisabled',['OPUS_GET_PHASE_INVERSION_DISABLED',['../group__opus__genericctls.html#gae9ad2f51fe4fe086f35e881682c4c247',1,'opus_defines.h']]],
   ['opus_5fget_5fpitch',['OPUS_GET_PITCH',['../group__opus__decoderctls.html#gaa89fc25eb35fc31a02b508562dd83820',1,'opus_defines.h']]],
   ['opus_5fget_5fprediction_5fdisabled',['OPUS_GET_PREDICTION_DISABLED',['../group__opus__encoderctls.html#ga6f174467d0e244917d1cc736f9033f1d',1,'opus_defines.h']]],
   ['opus_5fget_5fsample_5frate',['OPUS_GET_SAMPLE_RATE',['../group__opus__genericctls.html#gac8ad425424211faae6a0fbfb7c28bb51',1,'opus_defines.h']]],
@@ -144,6 +149,7 @@ var searchData=
   ['opus_5fset_5flsb_5fdepth',['OPUS_SET_LSB_DEPTH',['../group__opus__encoderctls.html#gaa23940eb477ff617edc14b8d66e104c0',1,'opus_defines.h']]],
   ['opus_5fset_5fmax_5fbandwidth',['OPUS_SET_MAX_BANDWIDTH',['../group__opus__encoderctls.html#ga4f88288e89c595c07c61db316cc45289',1,'opus_defines.h']]],
   ['opus_5fset_5fpacket_5floss_5fperc',['OPUS_SET_PACKET_LOSS_PERC',['../group__opus__encoderctls.html#gafda1c951dea919ba54432cd03827f1a9',1,'opus_defines.h']]],
+  ['opus_5fset_5fphase_5finversion_5fdisabled',['OPUS_SET_PHASE_INVERSION_DISABLED',['../group__opus__genericctls.html#ga10fa1f6eab136baf83c232afa989b6a8',1,'opus_defines.h']]],
   ['opus_5fset_5fprediction_5fdisabled',['OPUS_SET_PREDICTION_DISABLED',['../group__opus__encoderctls.html#ga0a73d613f6d9d601b32535fd37f58482',1,'opus_defines.h']]],
   ['opus_5fset_5fsignal',['OPUS_SET_SIGNAL',['../group__opus__encoderctls.html#gaaa87ccee4ae46aa6c9528e03c5122b89',1,'opus_defines.h']]],
   ['opus_5fset_5fvbr',['OPUS_SET_VBR',['../group__opus__encoderctls.html#ga34d09ae06cab7e1a6c49876249b67892',1,'opus_defines.h']]],
